@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////
 //
 //   XML documenting files to plain text conversion script 
-//   Last updated on April 12, 2022
+//   Last updated on July 18, 2022
 //
 //   This file is part of Logtalk <https://logtalk.org/>  
 //   Copyright 1998-2022 Paulo Moura <pmoura@logtalk.org>
@@ -34,7 +34,6 @@ var directory = WshShell.CurrentDirectory;
 var processor = "msxsl";
 // var processor = "xsltproc";
 // var processor = "xalan";
-// var processor = "sabcmd";
 // var processor = "saxon";
 
 if (WScript.Arguments.Unnamed.Length > 0) {
@@ -89,7 +88,7 @@ if (d_arg != "" && !FSObject.FolderExists(d_arg)) {
 } else if (d_arg != "")
 	directory = d_arg;
 
-if (p_arg != "" && p_arg != "msxsl" && p_arg != "xsltproc" && p_arg != "xalan" && p_arg != "sabcmd" && p_arg != "saxon") {
+if (p_arg != "" && p_arg != "msxsl" && p_arg != "xsltproc" && p_arg != "xalan" && p_arg != "saxon") {
 	WScript.Echo("Error! Unsupported XSLT processor:" + p_arg);
 	WScript.Echo("");
 	usage_help();
@@ -146,9 +145,6 @@ for (files.moveFirst(); !files.atEnd(); files.moveNext()) {
 			case "xalan" :
 				WshShell.Run("xalan -o \"" + txt_file + "\" \"" + file + "\" \"" + xslt + "\"", true);
 				break;
-			case "sabcmd" :
-				WshShell.Run("sabcmd \"" + xslt + "\" \"" + file + "\" \"" + txt_file + "\"", true);
-				break;
 			case "saxon" :
 				WshShell.Run("java net.sf.saxon.Transform -o:\"" + txt_file + "\" -s:\"" + file + "\" -xsl:\"" + xslt + "\"", true);
 				break;
@@ -172,7 +168,7 @@ function usage_help() {
 	WScript.Echo("");
 	WScript.Echo("Optional arguments:");
 	WScript.Echo("  d - output directory for the generated files (default is " + directory + ")");
-	WScript.Echo("  p - XSLT processor (msxsl, xsltproc, xalan, sabcmd, or saxon; default is " + processor + ")");
+	WScript.Echo("  p - XSLT processor (msxsl, xsltproc, xalan, or saxon; default is " + processor + ")");
 	WScript.Echo("");
 	WScript.Quit(1);
 }
